@@ -9,7 +9,6 @@ from pynhost import grammarhandler
 CONFIG_PATH = resource_filename(Requirement.parse("pynhost"), "pynhost_config.ini")
 
 def main():
-    print('trace')
     try:
         shared_dir = utilities.get_shared_directory(CONFIG_PATH)
     except:
@@ -34,7 +33,7 @@ def main():
         last_action = []
         add_space = False
         while True:
-            lines = utilities.get_buffer_lines()
+            lines = utilities.get_buffer_lines(CONFIG_PATH)
             time.sleep(.2)
             for line in lines:
                 result = {'remaining words': line.split(' ')}
